-- ok, this should be the textured polygon as triangle model

local Polygon={}

-- make a polygon for testing the feature
function Polygon.test(imagePath,colorize)
	--local imagePath="data/rock.png"
	
	-- i make just one quad from 2 triangles
	local x1=-100
	local x2=100
	local y1=-100
	local y2=100
	
	-- the texture will be repeated 4x4 tiles inside the quad
	local u1=0
	local v1=0
	local u2=4
	local v2=4
	
	-- use format x,y,z, u,v, nx,ny,nz, r,g,b,a
	-- where
	-- x,y,z		= vertex point where z is always 0 because this is not supposed to be a 3D game
	-- u,v			= texture UV coordinate
	-- nx,ny,nz	= normal always 0,0,-1 to face the camera
	-- r,g,b,a	= per vertex color where a is always 1, but when you do not set anything it will be white 1,1,1,1
	-- if you get the order of vertices wrong the triangle will dissappear
	-- when that happens look at window.lua and set the culling method to from "back" to "none" in window.lua
	local verts
	
	if colorize then
		verts={
			-- front face triangle 1
			{x1,y1, u1,v1, 1,0,0,1},
			{x2,y2, u2,v2, 1,1,0,1},	
			{x2,y1, u2,v1, 0,1,0,1},
			-- front face triangle 2
			{x1,y1, u1,v1, 1,0,0,1},
			{x1,y2, u1,v2, 1,1,0,1},
			{x2,y2, u2,v2, 1,1,0,1},	
		}
	else
		verts={
			-- front face triangle 1
			{x1,y1, u1,v1, 1,1,1,1},
			{x2,y2, u2,v2, 1,1,1,1},
			{x2,y1, u2,v1, 1,1,1,1},
			-- front face triangle 2
			{x1,y1, u1,v1, 1,1,1,1},
			{x1,y2, u1,v2, 1,1,1,1},
			{x2,y2, u2,v2, 1,1,1,1},
		}
	end
	
	-- the resulting polygon table
	local polygon=Polygon.make(imagePath,verts)
	return polygon
end

-- note : consider making an polygon shape out of color only
-- then using love.math.triangulate(vertices) of that polygon to get triangles
-- then calculate U,V coordinate for each pixel and you get a nice textured polygon
-- considering that i can calculate U,V based on position X,Y for example each 10 units of position is 1 unit of U,V

-- make an model from image and vertices
function Polygon.make(imagePath,verts)
	-- load textue from file
	local image=Resource.getImage(imagePath)
	
	-- make a model out of vertices and image
	-- note : static mean that the data will never change, look also for dynamic and stream when you need to edit something
	local mesh=love.graphics.newMesh(verts,"triangles","static")
	mesh:setTexture(image)
	
	-- and this will be the new polygon made out of triangles
	local polygon={
		-- each polygon has its own values that define it's position for X,Y then rotation angle and scale
		x=0,
		y=0,
		angle=0,
		scale=1,
		
		-- stored matrix so it changes in update and not in draw
		transform=love.math.newTransform(),
		
		-- the texture stored also only as reference
		image=image,
		
		-- vertices stored only for editation
		verts=verts,
		
		-- mesh of triangles
		mesh=mesh,
	}
	
	return polygon
end

-- draw the textured polygon model
function Polygon.draw(shader,polygon)
	love.graphics.push()
	love.graphics.applyTransform(polygon.transform)
	love.graphics.draw(polygon.mesh)
	love.graphics.pop()
end

-- set position of polygon
function Polygon.setPosition(polygon,x,y)
	polygon.x=x
	polygon.y=y
end

-- set rotation of polygon
function Polygon.setRotation(polygon,angle)
	polygon.angle=angle
end

-- set scale of polygon
function Polygon.setScale(polygon,scale)
	polygon.scale=scale
end

function Polygon.updateTransform(polygon)
	polygon.transform:reset()
	polygon.transform:translate(polygon.x,polygon.y)
	polygon.transform:rotate(polygon.angle)
	polygon.transform:scale(polygon.scale)
end

return Polygon