-- i just needed some window setup function

local Window={}

-- make a window based on conf.lua settings even for mobile app
function Window.make()
	local conf=love.conf({window={}})
	local settings={
		fullscreen=conf.window.fullscreen,
		vsync=conf.window.vsync,
		resizable=conf.window.resizable,
		borderless=conf.window.borderless,
		centered=true,
		minwidth=conf.window.minwidth,
		minheight=conf.window.minheight,
		display=conf.window.display,
		usedpiscale=conf.window.usedpiscale
	}
	
	local width=conf.window.width
	local height=conf.window.height
	local title=conf.window.title
	local filter=conf.filter
	local orientation=conf.window.orientation
	
	if love.system.getOS()=="Android" then
		settings.fullscreen=true
		settings.borderless=true
		settings.resizable=false
		local modes=love.window.getFullscreenModes(1)
		if modes~=nil and modes[1]~=nil then
			width=modes[1].width
			height=modes[1].height
		end
	end  
	
	love.window.setTitle(title)
	love.window.setMode(width,height,settings)
	love.window.setVSync(settings.vsync)
	love.window.setDisplaySleepEnabled(true)
	if settings.fullscreen then
		love.window.maximize()
	end
	
	love.graphics.setDefaultFilter(filter,filter,0)  
	love.keyboard.setKeyRepeat(true)
	love.graphics.setMeshCullMode("back")
	
	Window.conf=conf
	Window.filter=filter
	Window.wireframe=false
end

-- toggle between nearest and linear filters
function Window.toggleDefaultFilter()
	if Window.filter=="nearest" then
		Window.filter="linear"
	else
		Window.filter="nearest"
	end
	love.graphics.setDefaultFilter(Window.filter,Window.filter,0)
	Resource.updateImagesFilter(Window.filter)
end

-- toggle wireframe mode on/off
function Window.toggleWireframe()
	Window.wireframe=not Window.wireframe
end

return Window